@@ -17,10 +17,12 @@ tags_to_test = (
     "image-missing_caption",
     "image-no_caption",
     "image-mime_type",
+    "image-height_width",
     "featuredimage",
     "featuredimage-missing_caption",
     "featuredimage-no_caption",
     "featuredimage-mime_type",
+    "featuredimage-height_width",
     "horizontal_rule",
     "embed",
     "embed-missing_caption",
